Fix various typos, scattered over the code.
authorRobert P. J. Day <rpjday@crashcourse.ca>
Wed, 4 May 2016 08:47:31 +0000 (04:47 -0400)
committerTom Rini <trini@konsulko.com>
Fri, 6 May 2016 01:39:26 +0000 (21:39 -0400)
Spelling corrections for (among other things):

* environment
* override
* variable
* ftd (should be "fdt", for flattened device tree)
* embedded
* FTDI
* emulation
* controller

24 files changed:
arch/arm/cpu/armv8/fsl-layerscape/fsl_lsch3_speed.c
arch/arm/mach-uniphier/boot-mode/boot-mode.c
arch/mips/Kconfig
arch/powerpc/cpu/ppc4xx/denali_spd_ddr2.c
board/freescale/common/fsl_validate.c
board/freescale/mx28evk/README
cmd/fdt.c
cmd/mtdparts.c
doc/README.commands.spl
doc/README.marubun-pcmcia
doc/README.mxs
doc/SPI/README.sandbox-spi
doc/SPI/README.ti_qspi_flash
drivers/bios_emulator/x86emu/decode.c
drivers/dfu/Kconfig
drivers/net/macb.c
drivers/net/sh_eth.c
drivers/net/sh_eth.h
drivers/thermal/Kconfig
include/configs/hikey.h
include/configs/omap3_logic.h
include/configs/pengwyn.h
include/fdtdec.h
tools/moveconfig.py

index d580a43..a9b12a4 100644 (file)
@@ -180,7 +180,7 @@ ulong get_ddr_freq(ulong ctrl_num)
 
        /*
         * DDR controller 0 & 1 are on memory complex 0
-        * DDR controler 2 is on memory complext 1
+        * DDR controller 2 is on memory complext 1
         */
 #ifdef CONFIG_SYS_FSL_HAS_DP_DDR
        if (ctrl_num >= 2)
index 48e478c..b180f44 100644 (file)
@@ -114,7 +114,7 @@ static int do_mmcsetn(cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
 
 U_BOOT_CMD(
           mmcsetn,     1,      1,      do_mmcsetn,
-       "Set the first MMC (not SD) dev number to \"mmc_first_dev\" enviroment",
+       "Set the first MMC (not SD) dev number to \"mmc_first_dev\" environment",
        ""
 );
 #endif
index f852a1f..fe37d1f 100644 (file)
@@ -145,7 +145,7 @@ config MIPS_BOOT_ENV_LEGACY
          Enable this option if you want U-Boot to hand over the Yamon-style
          environment to the kernel. Information like memory size, initrd
          address and size will be prepared as zero-terminated key/value list.
-         The address of the enviroment is stored in register $a2.
+         The address of the environment is stored in register $a2.
 
 config MIPS_BOOT_FDT
        bool "Hand over a flattened device tree to Linux kernel"
index 916451a..455136c 100644 (file)
@@ -1151,7 +1151,7 @@ phys_size_t initdram(int board_type)
        dram_size *= ranks;
        debug("dram_size = %lu\n", dram_size);
 
-       /* Start the SDRAM controler */
+       /* Start the SDRAM controller */
        mtsdram(DDR0_02, DDR0_02_START_ENCODE(1));
        denali_wait_for_dlllock();
 
index 64e4e30..8c171b1 100644 (file)
@@ -812,9 +812,9 @@ static int calculate_cmp_img_sig(struct fsl_secboot_img_priv *img)
 }
 /* haddr - Address of the header of image to be validated.
  * arg_hash_str - Option hash string. If provided, this
- * overides the key hash in the SFP fuses.
+ * overrides the key hash in the SFP fuses.
  * img_addr_ptr - Optional pointer to address of image to be validated.
- * If non zero addr, this overides the addr of image in header,
+ * If non zero addr, this overrides the addr of image in header,
  * otherwise updated to image addr in header.
  * Acts as both input and output of function.
  * This pointer shouldn't be NULL.
index a248fb2..b8bee89 100644 (file)
@@ -45,7 +45,7 @@ or
 
 or
 
-"make mx28evk_spi_config"       - store enviroment variables into SPI NOR flash
+"make mx28evk_spi_config"       - store environment variables into SPI NOR flash
 
 Choose the target accordingly.
 
index 4c18962..898217f 100644 (file)
--- a/cmd/fdt.c
+++ b/cmd/fdt.c
@@ -1055,7 +1055,7 @@ static char fdt_help_text[] =
        "                                        <start> - addr of key blob\n"
        "                                                  default gd->fdt_blob\n"
 #endif
-       "NOTE: Dereference aliases by omiting the leading '/', "
+       "NOTE: Dereference aliases by omitting the leading '/', "
                "e.g. fdt print ethernet0.";
 #endif
 
index 86a4689..44b2c3a 100644 (file)
@@ -1742,7 +1742,7 @@ int mtdparts_init(void)
        debug("last_partition : %s\n", last_partition);
        debug("env_partition  : %s\n", current_partition);
 
-       /* if mtdids varible is empty try to use defaults */
+       /* if mtdids variable is empty try to use defaults */
        if (!ids) {
                if (mtdids_default) {
                        debug("mtdids variable not defined, using default\n");
index ac33273..cb3e0c8 100644 (file)
@@ -10,7 +10,7 @@ export has two subcommands:
        fdt: exports the FDT
 
 Call is:
-spl export <ftd|atags> [kernel_addr] [initrd_addr] [fdt_addr if fdt]
+spl export <fdt|atags> [kernel_addr] [initrd_addr] [fdt_addr if fdt]
 
 
 TYPICAL CALL
index d3563a3..0a363b2 100644 (file)
@@ -34,7 +34,7 @@ U-Boot MARUBUN MR-SHPC-01 PCMCIA controller driver
        ex.     #define CONFIG_PCMCIA_SLOT_A    1
 
     * CONFIG_SYS_MARUBUN_MRSHPC
-       This is MR-SHPC-01 PCMCIA controler base address.
+       This is MR-SHPC-01 PCMCIA controller base address.
        You should do the setting matched to your environment.
        ex.  #define CONFIG_SYS_MARUBUN_MRSHPC 0xb03fffe0
             ( for MS7722SE01 environment )
index 6ea73b9..4edf19f 100644 (file)
@@ -219,7 +219,7 @@ There are two possibilities when preparing an image writable to NAND flash.
 
           This script expects a working TFTP server containing the file
           "u-boot.nand" in it's root directory. This can be changed by
-          adjusting the "update_nand_full_filename" varible.
+          adjusting the "update_nand_full_filename" variable.
 
           To update the system, run the following in U-Boot prompt:
 
@@ -242,7 +242,7 @@ There are two possibilities when preparing an image writable to NAND flash.
 
           This script expects a working TFTP server containing the file
           "u-boot.sb" in it's root directory. This can be changed by
-          adjusting the "update_nand_firmware_filename" varible.
+          adjusting the "update_nand_firmware_filename" variable.
 
           To update the system, run the following in U-Boot prompt:
 
index bb73eaf..dfa845c 100644 (file)
@@ -1,7 +1,7 @@
 Sandbox SPI/SPI Flash Implementation
 ====================================
 
-U-Boot supports SPI and SPI flash emuation in sandbox. This must be enabled
+U-Boot supports SPI and SPI flash emulation in sandbox. This must be enabled
 using the --spi_sf paramter when starting U-Boot.
 
 For example:
index 9064739..5cc1fd0 100644 (file)
@@ -31,7 +31,7 @@ Can be used in:
 Memory mapped read mode
 -----------------------
 In this, SPI controller is configured using configuration port and then
-controler is switched to memory mapped port for data read.
+controller is switched to memory mapped port for data read.
 
 Driver
 ------
index da44c3d..a9a01b5 100644 (file)
@@ -241,7 +241,7 @@ no segment override. Address modes such as -3[BP] or 10[BP+SI] all refer to
 addresses relative to SS (ie: on the stack). So, at the minimum, all
 decodings of addressing modes would have to set/clear a bit describing
 whether the access is relative to DS or SS.  That is the function of the
-cpu-state-varible M.x86.mode. There are several potential states:
+cpu-state-variable M.x86.mode. There are several potential states:
 
     repe prefix seen  (handled elsewhere)
     repne prefix seen  (ditto)
index 4fe2219..6b92064 100644 (file)
@@ -3,8 +3,8 @@ menu "DFU support"
 config DFU_TFTP
        bool "DFU via TFTP"
        help
-         This option allows performing update of DFU managed medium with data
-         send via TFTP boot.
-         Detailed description of this feature can be found at ./doc/README.dfutftp
+         This option allows performing update of DFU-managed medium with data
+         sent via TFTP boot.
 
+         Detailed description of this feature can be found at ./doc/README.dfutftp
 endmenu
index be0659a..4bf8fa4 100644 (file)
@@ -120,7 +120,7 @@ static int macb_is_gem(struct macb_device *macb)
 static int gem_is_gigabit_capable(struct macb_device *macb)
 {
        /*
-        * The GEM controllers embeded in SAMA5D2 and SAMA5D4 are
+        * The GEM controllers embedded in SAMA5D2 and SAMA5D4 are
         * configured to support only 10/100.
         */
        return macb_is_gem(macb) && !cpu_is_sama5d2() && !cpu_is_sama5d4();
index 443a4da..2fa2016 100644 (file)
@@ -1,5 +1,5 @@
 /*
* sh_eth.c - Driver for Renesas ethernet controler.
  *
  * Copyright (C) 2008, 2011 Renesas Solutions Corp.
  * Copyright (c) 2008, 2011, 2014 2014 Nobuhiro Iwamatsu
index 5cb520c..3645f0e 100644 (file)
@@ -1,5 +1,5 @@
 /*
* sh_eth.h - Driver for Renesas SuperH ethernet controler.
  *
  * Copyright (C) 2008 - 2012 Renesas Solutions Corp.
  * Copyright (c) 2008 - 2012 Nobuhiro Iwamatsu
index 3c6b36d..8e22ea7 100644 (file)
@@ -1,7 +1,7 @@
 config DM_THERMAL
        bool "Driver support for thermal devices"
        help
-         Enable support for temporary-sensing devices. Some SoCs have on-chip
+         Enable support for temperature-sensing devices. Some SoCs have on-chip
          temperature sensors to permit warnings, speed throttling or even
          automatic power-off when the temperature gets too high or low. Other
          devices may be discrete but connected on a suitable bus.
index 83d9e10..ffcc4d2 100644 (file)
                                "initrd_high=0xffffffffffffffff\0" \
                                BOOTENV
 
/* Preserve enviroment on sd card */
 #define CONFIG_COMMAND_HISTORY
 
 #define CONFIG_ENV_SIZE                        0x1000
index 6c79643..3c11e2a 100644 (file)
 #define CONFIG_PREBOOT \
        "echo ======================NOTICE============================;"\
        "echo \"The u-boot environment is not set.\";"                  \
-       "echo \"If using a display a valid display varible for your panel\";" \
+       "echo \"If using a display a valid display variable for your panel\";" \
        "echo \"needs to be set.\";"                                    \
        "echo \"Valid display options are:\";"                          \
        "echo \"  2 == LQ121S1DG31     TFT SVGA    (12.1)  Sharp\";"    \
index 1f33bc6..816c571 100644 (file)
        "run mmcboot;" \
        "run nandboot;"
 
-/* NS16550 Configuration: primary UART via FDTI */
+/* NS16550 Configuration: primary UART via FTDI */
 #define CONFIG_SYS_NS16550_COM1                0x44e09000
 #define CONFIG_BAUDRATE                        115200
 
index fb88273..37d482a 100644 (file)
@@ -570,7 +570,7 @@ int fdtdec_check_fdt(void);
  * @param id           Compatible ID to look for
  * @param node_list    Place to put list of found nodes
  * @param maxcount     Maximum number of nodes to find
- * @return number of nodes found on success, FTD_ERR_... on error
+ * @return number of nodes found on success, FDT_ERR_... on error
  */
 int fdtdec_find_aliases_for_id(const void *blob, const char *name,
                        enum fdt_compat_id id, int *node_list, int maxcount);
index 6f71b55..68631b7 100755 (executable)
@@ -273,12 +273,12 @@ def log_msg(color_enabled, color, defconfig, msg):
         color_text(color_enabled, color, msg) + '\n'
 
 def update_cross_compile():
"""Update per-arch CROSS_COMPILE via enviroment variables
 
     The default CROSS_COMPILE values are available
     in the CROSS_COMPILE list above.
 
-    You can override them via enviroment variables
+    You can override them via environment variables
     CROSS_COMPILE_{ARCH}.
 
     For example, if you want to override toolchain prefixes
@@ -1,5 +1,5 @@
 /*
- * sh_eth.c - Driver for Renesas ethernet controler.
+ * sh_eth.c - Driver for Renesas ethernet controller.
  *
  * Copyright (C) 2008, 2011 Renesas Solutions Corp.
@@ -1,5 +1,5 @@
 /*
- * sh_eth.h - Driver for Renesas SuperH ethernet controler.
+ * sh_eth.h - Driver for Renesas SuperH ethernet controller.
  *
  * Copyright (C) 2008 - 2012 Renesas Solutions Corp.
@@ -1,7 +1,7 @@
                                BOOTENV
 
-/* Preserve enviroment on sd card */
+/* Preserve environment on sd card */
 #define CONFIG_COMMAND_HISTORY
 
@@ -273,12 +273,12 @@ def log_msg(color_enabled, color, defconfig, msg):
 
 def update_cross_compile():
-    """Update per-arch CROSS_COMPILE via enviroment variables
+    """Update per-arch CROSS_COMPILE via environment variables
 
     The default CROSS_COMPILE values are available